==> open-xchange-guard-backend-plugin_2.10.6.orig.tar.bz2: open-xchange-guard-backend-plugin-2.10.6/com.openexchange.guard.backend/src/com/openexchange/guard/mail/service/impl/CompositePGPMailRecognizer.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.guard.mail.service.impl;

import com.openexchange.exception.OXException;
import com.openexchange.mail.dataobjects.MailMessage;
import com.openexchange.mail.mime.crypto.PGPMailRecognizer;

/**
 * {@link CompositePGPMailRecognizer}
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.8.0
 */
public class CompositePGPMailRecognizer implements PGPMailRecognizer {

    private final PGPMailRecognizer[] recognizers;

    /**
     * Initializes a new {@link CompositePGPMailRecognizer}.
     *
     * @param recognizers A set of {@link PGPMailRecognizer}
     */
    public CompositePGPMailRecognizer(PGPMailRecognizer[] recognizers) {
        this.recognizers = recognizers;
    }

    /* (non-Javadoc)
     * @see com.openexchange.guard.mail.service.impl.PGPMailRecognizer#isPGPMessage(com.openexchange.mail.dataobjects.MailMessage)
     */
    @Override
    public boolean isPGPMessage(MailMessage message) throws OXException {
        if(recognizers != null) {
            for(PGPMailRecognizer recognizer : recognizers) {
                if(recognizer.isPGPMessage(message)) {
                    return true;
                }
            }
        }
        return false;
    }

    /* (non-Javadoc)
     * @see com.openexchange.mail.mime.crypto.PGPMailRecognizer#isPGPSignedMessage(com.openexchange.mail.dataobjects.MailMessage)
     */
    @Override
    public boolean isPGPSignedMessage(MailMessage message) throws OXException {
        if(recognizers != null) {
            for(PGPMailRecognizer recognizer : recognizers) {
                if(recognizer.isPGPSignedMessage(message)) {
                    return true;
                }
            }
        }
        return false;
    }
}

==> open-xchange-guard-backend-plugin_2.10.7.orig.tar.bz2: open-xchange-guard-backend-plugin-2.10.7/com.openexchange.guard.backend/src/com/openexchange/guard/mail/service/impl/CompositePGPMailRecognizer.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.guard.mail.service.impl;

import javax.mail.Message;
import com.openexchange.exception.OXException;
import com.openexchange.mail.dataobjects.MailMessage;
import com.openexchange.mail.mime.crypto.PGPMailRecognizer;

/**
 * {@link CompositePGPMailRecognizer}
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.8.0
 */
public class CompositePGPMailRecognizer implements PGPMailRecognizer {

    private final PGPMailRecognizer[] recognizers;

    /**
     * Initializes a new {@link CompositePGPMailRecognizer}.
     *
     * @param recognizers A set of {@link PGPMailRecognizer}
     */
    public CompositePGPMailRecognizer(PGPMailRecognizer[] recognizers) {
        this.recognizers = recognizers;
    }

    /* (non-Javadoc)
     * @see com.openexchange.guard.mail.service.impl.PGPMailRecognizer#isPGPMessage(com.openexchange.mail.dataobjects.MailMessage)
     */
    @Override
    public boolean isPGPMessage(MailMessage message) throws OXException {
        if(recognizers != null) {
            for(PGPMailRecognizer recognizer : recognizers) {
                if(recognizer.isPGPMessage(message)) {
                    return true;
                }
            }
        }
        return false;
    }

    /* (non-Javadoc)
     * @see com.openexchange.mail.mime.crypto.PGPMailRecognizer#isPGPSignedMessage(com.openexchange.mail.dataobjects.MailMessage)
     */
    @Override
    public boolean isPGPSignedMessage(MailMessage message) throws OXException {
        if(recognizers != null) {
            for(PGPMailRecognizer recognizer : recognizers) {
                if(recognizer.isPGPSignedMessage(message)) {
                    return true;
                }
            }
        }
        return false;
    }

    @Override
    public boolean isPGPMessage(Message msg) throws OXException {
        if (recognizers != null) {
            for (PGPMailRecognizer recognizer : recognizers) {
                if (recognizer.isPGPMessage(msg)) {
                    return true;
                }
            }
        }
        return false;
    }
}
